==> react-fast-highlight-2.2.0.tgz: package/lib/__tests__/BareHighlight.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = _interopRequireWildcard(require("enzyme"));

var _enzymeAdapterReact = _interopRequireDefault(require("enzyme-adapter-react-16"));

var _highlight = _interopRequireDefault(require("highlight.js"));

var _BareHighlight = _interopRequireDefault(require("../BareHighlight"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env jest */
_enzyme.default.configure({
  adapter: new _enzymeAdapterReact.default()
});

test('no language - calls correct highlightCall', function (done) {
  var hljs = {
    highlightAuto: jest.fn(function () {
      return {
        value: 'othertest',
        language: 'xml'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs
  }, "test"));
  setTimeout(function () {
    expect(wrapper.state('language')).toBe('xml');
    expect(wrapper.state('highlightedCode')).toBe('othertest');
    expect(hljs.highlightAuto).toHaveBeenCalledWith('test', []);
    expect(hljs.highlightAuto).toHaveBeenCalledTimes(1);
    done();
  }, 1);
});
test('can correctly rerender code', function (done) {
  var value = 'initalresult';
  var hljs = {
    highlightAuto: jest.fn(function () {
      return {
        value: value,
        language: 'xml'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs
  }, "test"));
  setTimeout(function () {
    value = 'changed';
    wrapper.setProps({
      children: 'newtest'
    });
    setTimeout(function () {
      expect(wrapper.state('language')).toBe('xml');
      expect(wrapper.state('highlightedCode')).toBe('changed');
      expect(hljs.highlightAuto).toHaveBeenCalledWith('newtest', []);
      expect(hljs.highlightAuto).toHaveBeenCalledTimes(2);
      done();
    }, 1);
  }, 1);
});
test('one language - calls correct highlightCall', function (done) {
  var hljs = {
    highlight: jest.fn(function () {
      return {
        value: 'othertest',
        language: 'js'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs,
    languages: ['js']
  }, "test"));
  setTimeout(function () {
    expect(wrapper.state('language')).toBe('js');
    expect(wrapper.state('highlightedCode')).toBe('othertest');
    expect(hljs.highlight).toHaveBeenCalledWith('js', 'test');
    expect(hljs.highlight).toHaveBeenCalledTimes(1);
    done();
  }, 1);
});
test('multiple languages - calls correct highlightCall', function (done) {
  var hljs = {
    highlightAuto: jest.fn(function () {
      return {
        value: 'othertest',
        language: 'js'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs,
    languages: ['js', 'html']
  }, "test"));
  setTimeout(function () {
    expect(wrapper.state('language')).toBe('js');
    expect(wrapper.state('highlightedCode')).toBe('othertest');
    expect(hljs.highlightAuto).toHaveBeenCalledWith('test', ['js', 'html']);
    expect(hljs.highlightAuto).toHaveBeenCalledTimes(1);
    done();
  }, 1);
});
test('className is passed through', function () {
  expect(_react.default.createElement(_BareHighlight.default, {
    highlightjs: _highlight.default,
    className: "foobar"
  }, "test")).toMatchReactSnapshot();
});

==> react-fast-highlight-2.2.1.tgz: package/lib/__tests__/BareHighlight.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = _interopRequireWildcard(require("enzyme"));

var _enzymeAdapterReact = _interopRequireDefault(require("enzyme-adapter-react-16"));

var _highlight = _interopRequireDefault(require("highlight.js"));

var _BareHighlight = _interopRequireDefault(require("../BareHighlight"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env jest */
_enzyme.default.configure({
  adapter: new _enzymeAdapterReact.default()
});

test('no language - calls correct highlightCall', function (done) {
  var hljs = {
    highlightAuto: jest.fn(function () {
      return {
        value: 'othertest',
        language: 'xml'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs
  }, "test"));
  setTimeout(function () {
    expect(wrapper.state('language')).toBe('xml');
    expect(wrapper.state('highlightedCode')).toBe('othertest');
    expect(hljs.highlightAuto).toHaveBeenCalledWith('test', []);
    expect(hljs.highlightAuto).toHaveBeenCalledTimes(1);
    done();
  }, 1);
});
test('can correctly rerender code', function (done) {
  var value = 'initalresult';
  var hljs = {
    highlightAuto: jest.fn(function () {
      return {
        value: value,
        language: 'xml'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs
  }, "test"));
  setTimeout(function () {
    value = 'changed';
    wrapper.setProps({
      children: 'newtest'
    });
    setTimeout(function () {
      expect(wrapper.state('language')).toBe('xml');
      expect(wrapper.state('highlightedCode')).toBe('changed');
      expect(hljs.highlightAuto).toHaveBeenCalledWith('newtest', []);
      expect(hljs.highlightAuto).toHaveBeenCalledTimes(2);
      done();
    }, 1);
  }, 1);
});
test('one language - calls correct highlightCall', function (done) {
  var hljs = {
    highlight: jest.fn(function () {
      return {
        value: 'othertest',
        language: 'js'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs,
    languages: ['js']
  }, "test"));
  setTimeout(function () {
    expect(wrapper.state('language')).toBe('js');
    expect(wrapper.state('highlightedCode')).toBe('othertest');
    expect(hljs.highlight).toHaveBeenCalledWith('js', 'test');
    expect(hljs.highlight).toHaveBeenCalledTimes(1);
    done();
  }, 1);
});
test('multiple languages - calls correct highlightCall', function (done) {
  var hljs = {
    highlightAuto: jest.fn(function () {
      return {
        value: 'othertest',
        language: 'js'
      };
    })
  };
  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_BareHighlight.default, {
    highlightjs: hljs,
    languages: ['js', 'html']
  }, "test"));
  setTimeout(function () {
    expect(wrapper.state('language')).toBe('js');
    expect(wrapper.state('highlightedCode')).toBe('othertest');
    expect(hljs.highlightAuto).toHaveBeenCalledWith('test', ['js', 'html']);
    expect(hljs.highlightAuto).toHaveBeenCalledTimes(1);
    done();
  }, 1);
});
test('className is passed through', function () {
  expect(_react.default.createElement(_BareHighlight.default, {
    highlightjs: _highlight.default,
    className: "foobar"
  }, "test")).toMatchReactSnapshot();
});
